@@ -5,16 +5,16 @@
  *  Copyright 2005 Novell, Inc. (www.novell.com)
  *
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
+ *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
@@ -419,7 +419,8 @@ connect_to_server_wrapper (CamelIMAP4Engine *engine, CamelException *ex)
 	const char *port;
 	char *serv;
 	
-	if ((command = camel_url_get_param (service->url, "command")))
+	if (camel_url_get_param(service->url, "use_command")
+	    &&(command = camel_url_get_param (service->url, "command")))
 		return connect_to_server_process (engine, command, ex);
 	
 	if ((ssl_mode = camel_url_get_param (service->url, "use_ssl"))) {
