@@ -3,7 +3,7 @@
 /* Copyright (C) 2001-2004 Novell, Inc.
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -11,7 +11,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
@@ -280,6 +280,11 @@ e2k_context_new (const char *uri)
 	suri = soup_uri_new (uri);
 	if (!suri)
 		return NULL;
+	
+	if (!suri->host) {
+		soup_uri_free (suri);
+		return NULL;
+	}
 
 	ctx = g_object_new (E2K_TYPE_CONTEXT, NULL);
 	ctx->priv->owa_uri = g_strdup (uri);
