@@ -7,15 +7,15 @@
  * Copyright 2003, Novell, Inc.
  *
  * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU General Public 
+ * modify it under the terms of version 2 of the GNU Lesser General Public 
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -246,8 +246,8 @@ e_gw_container_set_from_soap_parameter (EGwContainer *container, SoupSoapParamet
 			container->priv->type = E_GW_CONTAINER_TYPE_ROOT ;
 		else if (!strcmp (value, "Mailbox")) 
 			container->priv->type = E_GW_CONTAINER_TYPE_INBOX ;
-		else if (!strcmp (value, "Outbox")) 
-			container->priv->type = E_GW_CONTAINER_TYPE_OUTBOX ;
+		else if (!strcmp (value, "SentItems")) 
+			container->priv->type = E_GW_CONTAINER_TYPE_SENT;
 		else if (!strcmp (value, "Calendar")) 
 			container->priv->type = E_GW_CONTAINER_TYPE_CALENDAR ;
 		else if (!strcmp (value, "Contacts")) 
